---
title: EZ-CV
link: https://github.com/Descent098/ezcv
image: https://raw.githubusercontent.com/Descent098/ezcv/master/.github/logo.png
---

A python-based static site generator for setting up a CV/Resume site